@@ -15,7 +15,7 @@ hcf.perm <- function(x1, x2, B = 999) {
 
   pft <- numeric(B)
   for (i in 1:B) {
-    ind <- sample(ina, n)
+    ind <- Rfast2::Sample(ina, n)
     S <- rowsum(x, ind)
     Ri <- sqrt( Rfast::rowsums(S^2) )
     pft[i] <- (n - 2) * (sum(Ri) - R) / ( n - sum(Ri) )
